@@ -48,8 +48,10 @@ def deflog():
     return log
 
 
-def do_connect(ssid, password):
+def do_connect(ssid, password, log):
     time.sleep(1)
+    log.debug("Calling client connect")
+    ciu_client.service = None
     ciu_client.ciu_connect(ssid, password)
 
 
@@ -95,7 +97,7 @@ def create_app(log):
         ssid = urllib.parse.unquote(request.form["ssid"])
         password = request.form["password"].encode()
 
-        p = Process(target=do_connect, args=(ssid, password))
+        p = Process(target=do_connect, args=(ssid, password, log))
         p.start()
 
         log.info("connect.html - ssid {0}".format(ssid))
@@ -128,7 +130,7 @@ def main():
     ciu_client.ciu_points()
 
     app = create_app(log)
-    app.run(host="0.0.0.0", port=80, debug=True, threaded=True)
+    app.run(host="0.0.0.0", port=80, debug=False, threaded=True)
 
 
 if __name__ == '__main__':
